@@ -16,6 +16,8 @@ QueueView::QueueView(Spotify::Session* pSession, QWidget* parent)
 
     m_pCurrTrack = NULL;
     m_currQueuePos = 0;
+    m_Active = false;
+    m_UpdateBufPos = true;
 
     //define slider used for displaying buffering and track progress
     m_pProgressSlider = new CustomSlider(this,510,40);
@@ -35,6 +37,7 @@ QueueView::QueueView(Spotify::Session* pSession, QWidget* parent)
     connect(m_pSession,SIGNAL(coverArtReady(QImage)),SLOT(OnAlbumCoverReady(QImage)));
     connect(m_pSession,SIGNAL(playing(bool)),SLOT(OnPlayingState(bool)));
     connect(m_pSession,SIGNAL(playbackFinished()),SLOT(OnTrackPlaybackFinished()));
+    connect(m_pSession,SIGNAL(bufferNextTrack()),SLOT(OnBufferNextTrack()));
     connect(&m_TrackInfo,SIGNAL(itemActivated(QListWidgetItem*)),SLOT(OnTrackActivated(QListWidgetItem*)));
     connect(&m_PauseResumeBtn,SIGNAL(clicked()),SLOT(OnPauseResumeToggle()));
     connect(&m_PrevBtn,SIGNAL(clicked()),SLOT(OnPrevTrackBtn()));
@@ -108,33 +111,57 @@ void QueueView::setNowPlaying(QList<Spotify::Track*> queue, int currQueuePos, bo
 
            m_PlayQueue = queue;
 
-            m_pCurrTrack = m_PlayQueue.at(currQueuePos);
+           addTracks(m_PlayQueue); //add track data to track list
 
-            m_currQueuePos = currQueuePos;
+           if(currQueuePos!=-1)
+           {
+               m_pCurrTrack = m_PlayQueue.at(currQueuePos);
 
-            emit playQueuePosUpdated(m_currQueuePos);
+               m_currQueuePos = currQueuePos;
 
-            addTracks(m_PlayQueue); //add track data to track list
+              emit playQueuePosUpdated(m_currQueuePos);
 
-            m_TrackInfo.setCurrentRow(m_currQueuePos);
+              m_TrackInfo.setCurrentRow(m_currQueuePos);
 
-            if(m_pCurrTrack)
-            {
-                loadTrackData(m_pCurrTrack);
+             if(m_pCurrTrack)
+             {
+                 loadTrackData(m_pCurrTrack);
+             }
+
+             m_PauseResumeBtn.setEnabled(true);
+             m_PauseResumeBtn.setChecked(playing);
+
+             //set the state of the progress indicators
+             OnTrackPosUpdated(currBufPos);
+             OnPlaybackPositionUpdated(currPlaybackPos);
             }
+           else
+           {
+               clearViewSelection();
+           }
+}
 
-            m_PauseResumeBtn.setEnabled(true);
-            m_PauseResumeBtn.setChecked(playing);
-			
-			//set the state of the progress indicators
-			
-			OnTrackPosUpdated(currBufPos);
-			OnPlaybackPositionUpdated(currPlaybackPos);
+void QueueView::clearViewSelection()
+{
+    //clear the current view selection (i.e., set to state when no track is active)
+
+    m_ArtistName.clear();
+
+    m_AlbumCoverContainer.clear();
+
+    m_TrackInfo.clearSelection();
+
+    m_pProgressSlider->setPos1(0);
+    m_pProgressSlider->setPos2(0);
+    m_pProgressSlider->setText("");
+
+    m_PauseResumeBtn.setChecked(false);
+    m_PauseResumeBtn.setEnabled(false);
 }
 
 void QueueView::OnPlayingState(bool state)
 {
-    if(isVisible())
+    if(m_Active)
     {
         if(state)
         { //playing state
@@ -147,6 +174,36 @@ void QueueView::OnPlayingState(bool state)
     }
 }
 
+void QueueView::OnBufferNextTrack()
+{
+    Spotify::Error error;
+   //invoked when ready to start buffering the following track (pre-buffering mode)
+    if(m_Active) //current view instance is active
+    {
+        if(m_currQueuePos < m_PlayQueue.size()-1)
+        {
+            Spotify::Track* track = m_PlayQueue.at(m_currQueuePos+1);
+            if(m_pCurrTrack)
+            {
+                m_pSession->setNewTrackStarted(true); //indicate start of new track audio buffer data (in playback thread FIFO)
+                error = m_pSession->play(track,true); //initiate buffering of track
+                if(error.isError())
+                {
+                    qDebug()<< "Error starting track playback: " << error.toString();
+                }
+                m_UpdateBufPos = false; //do not update the buffering position (current track still playing)
+            }
+        }
+        else
+        {
+
+          //end of playqueue reached, set next track pos to end of current track
+            m_pSession->setNewTrackStarted(false);
+            m_pSession->setNextTrackStartPos();
+        }
+    }
+}
+
 void QueueView::loadTrackData(Spotify::Track* track)
 {
     //Load track data for specified track (e.g., album cover art)
@@ -262,11 +319,9 @@ void QueueView::OnTrackPosUpdated(qint64 trackPos)
 {
     //Track buffering position has been updated
 
-    if(isVisible())
+    if(m_Active && m_UpdateBufPos)
     {
-
         int currPos = (trackPos*510) / (m_currTrackDuration*1000);
-
         m_pProgressSlider->setPos1(currPos); //set curr. slider position
     }
 
@@ -276,16 +331,14 @@ void QueueView::OnPlaybackPositionUpdated(qint64 trackPos)
 {
     //Track playback position updated
 
-    if(isVisible())
+    if(m_Active)
     {
 
         QString strCurrTrackProgressInfo, strCurrPlaybackPos, strCurrTrackDuration;
 
         QTextStream outStream(&strCurrTrackProgressInfo);
 
-        QTime currTrackPos(0,trackPos/60000,(trackPos/1000)%60,0);
-
-        qApp->processEvents(); //process any pending events
+        QTime currTrackPos(trackPos/3600000,trackPos/60000,(trackPos/1000)%60,0);
 
         if(m_pCurrTrack)
         { //set track progress info in format current playback position / total track duration
@@ -317,6 +370,12 @@ void QueueView::OnPauseResumeToggle()
     }
 }
 
+void QueueView::setActive(bool active)
+{
+    //set whether the current instance is active (i.e., whether signals should be processed)
+    m_Active = active;
+}
+
 void QueueView::OnNextTrackBtn()
 {
     //move to next track in play queue
@@ -381,17 +440,18 @@ void QueueView::OnPrevTrackBtn()
 
 void QueueView::OnTrackPlaybackFinished()
 {
-    if(isVisible())
+    if(m_Active)
     {
         //Playback of current track has finished
         //move to next track in play queue, if possible
 
+        qDebug() << "Playback finished..";
+
         Spotify::Error error;
 
         if(m_currQueuePos < m_PlayQueue.size()-1)
         {
             m_currQueuePos++;
-            qDebug()<< "New queue pos: " << m_currQueuePos;
             m_pCurrTrack = m_PlayQueue.at(m_currQueuePos);
             if(m_pCurrTrack)
             {
@@ -399,11 +459,19 @@ void QueueView::OnTrackPlaybackFinished()
                 m_pProgressSlider->setPos2(0);
                 m_TrackInfo.setCurrentRow(m_currQueuePos);
                 loadTrackData(m_pCurrTrack);
-                qDebug()<<"Starting track at pos " << m_currQueuePos << " in playqueue";
-                error = m_pSession->play(m_pCurrTrack); //initiate track playback
-                if(error.isError())
+                if(!m_pSession->getPreBufferingActive()) //pre-buffering is not active, buffering / playback should be initiated
                 {
-                    qDebug()<< "Error starting track playback: " << error.toString();
+                    error = m_pSession->play(m_pCurrTrack); //initiate track playback
+                    if(error.isError())
+                    {
+                        qDebug()<< "Error starting track playback: " << error.toString();
+                    }
+                }
+                else
+                { //track pre-buffering mode active; reset playback position and playing state
+                    m_pSession->setPlaybackPos(0); //reset current playback position
+                    m_UpdateBufPos = true; //allow update of buffering state
+                    OnTrackPosUpdated(m_pSession->getBufferingPos()); //update the current buffering state
                 }
                 emit playQueuePosUpdated(m_currQueuePos); //emit pos updated
             }
@@ -411,10 +479,7 @@ void QueueView::OnTrackPlaybackFinished()
         else
         {
             //end of playback queue reached
-            m_PauseResumeBtn.setChecked(false);
-            m_PauseResumeBtn.setEnabled(false);
-            m_pProgressSlider->setPos1(0);
-            m_pProgressSlider->setPos2(0);
+            clearViewSelection();
             emit playQueuePosUpdated(-1); //emit pos updated (indicates that playqueue has reached the end)
         }
     }
@@ -423,7 +488,7 @@ void QueueView::OnTrackPlaybackFinished()
 void QueueView::OnAlbumCoverReady(QImage image)
 {
     //Album coverart has been loaded (for currently selected track)
-    if(isVisible())
+    if(m_Active)
     {
         m_AlbumCoverContainer.setPixmap(QPixmap::fromImage(image));
     }
