@@ -32,6 +32,8 @@ public:
 
     void setNowPlaying(QList<Spotify::Track*> queue, int currQueuePos, bool playing, qint64 currPlaybackPos = 0, qint64 currBufPos = 0);
 
+    void setActive(bool active); //set whether the current instance is active (i.e., whether signals should be processed)
+
 private:
 
     QWidget m_MainLayout;
@@ -71,10 +73,17 @@ private:
 
     QList<Spotify::Track*> m_PlayQueue; //current play queue
 
+    bool m_Active; //TRUE in case current queueview instance is active (i.e., handles signals)
+
+    bool m_UpdateBufPos; //TRUE in case buffering position should be updated
+
     void addTracks(QList<Spotify::Track*> trackList); //add tracks from specified tracklist to main listview
 
     void loadTrackData(Spotify::Track* track); //load data for specified track, e.g., album cover art
 
+    void clearViewSelection(); //clear the current view selection (i.e., set to state when no track is active)
+
+
 private slots:
 
     void OnTrackActivated(QListWidgetItem* currTrack);
@@ -86,6 +95,7 @@ private slots:
     void OnPlayingState(bool state);
     void OnNextTrackBtn();
     void OnPrevTrackBtn();
+    void OnBufferNextTrack();
 
 signals:
 
