@@ -410,7 +410,7 @@ void TrackView::addTracks(QList<Spotify::Track*> trackList)
                  QTableWidgetItem* artistName = new QTableWidgetItem();
                  QTableWidgetItem* albumName = new QTableWidgetItem();
 
-                 trackName->setText(currTrack->getName() + " (" + QString::number(currTrack->getPopularity())+")");
+                 trackName->setText(currTrack->getName());
                  trackName->setData(Qt::UserRole,trackPos); //associate position in track instances list with list item
                  if(currTrack->getArtist())
                      artistName->setText(currTrack->getArtist()->getName());
