@@ -15,10 +15,12 @@
 #include <QtGui/QPushButton>
 #include <QtGui/QCloseEvent>
 #include <QSettings>
+#include <QMessageBox>
 #include <QFont>
 #include <QtMaemo5/QMaemo5InformationBox>
 #include <qspotify_src/spotifysession.h>
 #include "logindialog.h"
+#include "SettingsDialog.h"
 #include "TrackView.h"
 #include "QueueView.h"
 #include "SpectrumAnalyzer.h"
@@ -43,6 +45,8 @@ private:
 
     LoginDialog* m_pLoginDlg;
 
+    SettingsDialog* m_pSettingsDlg;
+
     TrackView* m_pTrackView;
 
     QueueView* m_pQueueView;
@@ -81,6 +85,8 @@ private:
 
     void logout(); //logout current user and display the login dialog
 
+    QMessageBox m_AboutDlg; //App About dialog instance
+
 
 private slots:
 
@@ -99,6 +105,8 @@ private slots:
      void OnTrackPosUpdated(qint64 pos);
      void OnPlaybackPositionUpdated(qint64 pos);
      void OnPlaybackTokenLost();
+     void OnActiveQueueViewChanged(bool active);
+     void OnSettingsSaved();
 
 signals:
 
