@@ -35,6 +35,25 @@ namespace Spotify
 
             void init(); //init the current Spotify session
 
+            void setMinBufferSize(qint32 secs); //set the size of the internal FIFO queue used to hold audio data
+
+            void setPreBufferingActive(bool active); //set whether track pre-buffering is active (i.e., buffer next track data in advance)
+
+            bool getPreBufferingActive(); //returns current pre-buffering state
+
+            void setNextTrackStartPos(); //set the next track start position in the audio FIFO
+
+            void setNewTrackStarted(bool started); //indicate start of new track audio buffer data (in playback thread FIFO)
+
+            void setPlaybackPos(qint64 pos);
+
+            void setBufferingPos(qint64 pos);
+
+            qint64 getBufferingPos(); //returns the current track buffering position
+
+            void setPlaying(bool playing);
+
+
             /**
              * Pointer to the Session object. Used to map
              * C-callbacks to C++ members.
@@ -53,6 +72,9 @@ namespace Spotify
 
             QTimer *m_pProcEvtTimer;
 
+            bool m_preBufActive; //true if track pre-buffering is enabled
+
+
 
             /**
              * Audio playback thread
@@ -89,8 +111,9 @@ namespace Spotify
             /**
              * Start playback of a Spotify::Track
              * @param track Track to play.
+             * @param preBuffer Track should be buffered only (at end of current FIFO)
              */
-            Spotify::Error play( Spotify::Track* track );
+            Spotify::Error play( Spotify::Track* track, bool preBuffer = false);
 
             /**
              * Seek to a given position in the stream.
@@ -275,7 +298,7 @@ namespace Spotify
             void OnTracksAdded(sp_playlist* pl, sp_track* const* tracks, int num_tracks, int position);
             void OnPlaylistMetadataUpdated(sp_playlist* pl);
             void OnImageLoaded(sp_image* image, void* userdata);
-            void OnMusicDelivery(const sp_audioformat* format, QByteArray buffer);
+            void OnMusicDelivery(int num_frames, const sp_audioformat* format, QByteArray buffer);
             void OnSearchComplete(sp_search* search);
             void OnResumeBuffering();
             void OnPlaybackPositionUpdated(qint64 duration);
@@ -431,10 +454,12 @@ namespace Spotify
              */
             void playlistMetadataUpdated(sp_playlist*);
 
-            void onMusicDelivery(const sp_audioformat*, QByteArray);
+            void onMusicDelivery(int, const sp_audioformat*, QByteArray);
 
             void onSearchComplete(sp_search*);
 
+            void bufferNextTrack();
+
 
         private:
 
@@ -454,6 +479,8 @@ namespace Spotify
             qint64 m_trackPos; //current track playback position
             bool m_playing;
 
+            QList<qint64> m_bufferPosList; //used for track pre-buffering; list of track buffering states
+
             // For mapping sp_playlist pointers to Spotify::Playlist pointers
             QHash< sp_playlist*, Spotify::Playlist* > m_playlistHash;
 
